@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package JSON::Schema::Modern; # git description: v0.526-10-g2a71a34d
+package JSON::Schema::Modern; # git description: v0.527-10-g4314fc22
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Validate data against a schema
 # KEYWORDS: JSON Schema data validation structure specification
 
-our $VERSION = '0.527';
+our $VERSION = '0.528';
 
 use 5.020;  # for fc, unicode_strings features
 use Moo;
@@ -500,14 +500,13 @@ sub _eval_subschema ($self, $data, $schema, $state) {
       next if $keyword ne '$ref' and exists $schema->{'$ref'} and $state->{spec_version} eq 'draft7';
 
       delete $unknown_keywords{$keyword};
-
-      my $method = '_eval_keyword_'.($keyword =~ s/^\$//r);
       $state->{keyword} = $keyword;
 
-      if ($vocabulary->can($method)) {
+      my $method = '_eval_keyword_'.($keyword =~ s/^\$//r);
+      if (my $sub = $vocabulary->can($method)) {
         my $error_count = $state->{errors}->@*;
 
-        if (not $vocabulary->$method($data, $schema, $state)) {
+        if (not $sub->($vocabulary, $data, $schema, $state)) {
           warn 'result is false but there are no errors (keyword: '.$keyword.')'
             if $error_count == $state->{errors}->@*;
           $valid = 0;
@@ -518,7 +517,7 @@ sub _eval_subschema ($self, $data, $schema, $state) {
       }
 
       if (my $sub = $state->{callbacks}{$keyword}) {
-        $sub->($schema, $state);
+        $sub->($data, $schema, $state);
       }
 
       push @new_annotations, $state->{annotations}->@[$#new_annotations+1 .. $state->{annotations}->$#*];
@@ -529,7 +528,7 @@ sub _eval_subschema ($self, $data, $schema, $state) {
 
   if ($valid) {
     push $state->{annotations}->@*, @new_annotations;
-    annotate_self(+{ %$state, keyword => $_, unknown => 1 }, $schema)
+    annotate_self(+{ %$state, keyword => $_, _unknown => 1 }, $schema)
       foreach sort keys %unknown_keywords;
   }
 
@@ -779,7 +778,7 @@ sub _fetch_from_uri ($self, $uri) {
       my $document = $resource->{document};
       my $closest_resource = first { !length($_->[1]{path})       # document root
           || length($document_path)
-            && path($_->[1]{path})->subsumes($document_path) }    # path is above present location
+            && $document_path =~ m{^\Q$_->[1]{path}\E(?:/|\z)} }  # path is above present location
         sort { length($b->[1]{path}) <=> length($a->[1]{path}) }  # sort by length, descending
         grep { not length Mojo::URL->new($_->[0])->fragment }     # omit anchors
         $document->resource_pairs;
@@ -851,7 +850,8 @@ has _encoding => (
   lazy => 1,
   default => sub ($self) {
     +{
-      'base64' => sub ($content_ref) {
+      identity => sub ($content_ref) { $content_ref },
+      base64 => sub ($content_ref) {
         die "invalid characters in base64 string"
           if $content_ref->$* =~ m{[^A-Za-z0-9+/=]} or $content_ref->$* =~ m{=(?=[^=])};
         require MIME::Base64; \ MIME::Base64::decode($content_ref->$*);
@@ -876,7 +876,7 @@ JSON::Schema::Modern - Validate data against a schema
 
 =head1 VERSION
 
-version 0.527
+version 0.528
 
 =head1 SYNOPSIS
 
@@ -1075,7 +1075,7 @@ For example, to find the locations where all C<$ref> keywords are applied B<succ
   my @used_ref_at;
   $js->evaluate($data, $schema_or_uri, {
     callbacks => {
-      '$ref' => sub ($schema, $state) {
+      '$ref' => sub ($data, $schema, $state) {
         push @used_ref_at, $state->{data_path};
       }
     },
@@ -1196,6 +1196,10 @@ Encodings handled natively are:
 
 =item *
 
+C<identity>
+
+=item *
+
 C<base64>
 
 =back
