@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Document;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: One JSON Schema document
 
-our $VERSION = '0.527';
+our $VERSION = '0.528';
 
 use 5.020;
 use Moo;
@@ -139,11 +139,11 @@ around _add_resources => sub {
 };
 
 # shims for Mojo::JSON::Pointer
-sub data { goto \&schema }
+sub data { shift->schema(@_) }
 sub FOREIGNBUILDARGS { () }
 
 # for JSON serializers
-sub TO_JSON { goto \&schema }
+sub TO_JSON { shift->schema }
 
 sub BUILD ($self, $args) {
   croak 'canonical_uri cannot contain a fragment' if defined $self->canonical_uri->fragment;
@@ -217,7 +217,7 @@ JSON::Schema::Modern::Document - One JSON Schema document
 
 =head1 VERSION
 
-version 0.527
+version 0.528
 
 =head1 SYNOPSIS
 
