@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Vocabulary::Core;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Implementation of the JSON Schema Core vocabulary
 
-our $VERSION = '0.527';
+our $VERSION = '0.528';
 
 use 5.020;
 use Moo;
@@ -132,8 +132,7 @@ sub _traverse_keyword_schema ($self, $schema, $state) {
 
   # remember, if we don't have a sibling $id, we must be at the document root with no identifiers
   if ($state->{identifiers}->@*) {
-    $state->{identifiers}[-1]{specification_version} = $state->{spec_version};
-    $state->{identifiers}[-1]{vocabularies} = $state->{vocabularies};
+    $state->{identifiers}[-1]->@{qw(specification_version vocabularies)} = $state->@{qw(spec_version vocabularies)};
   }
 
   return 1;
@@ -346,7 +345,7 @@ JSON::Schema::Modern::Vocabulary::Core - Implementation of the JSON Schema Core
 
 =head1 VERSION
 
-version 0.527
+version 0.528
 
 =head1 DESCRIPTION
 
